@@ -22,5 +22,5 @@ if __name__ == '__main__':
         app.application.start()
     except Exception as e:
         app.application.stop()
-        app.application.handleError(e)
+        raise e
         sys.exit(1)
\ No newline at end of file
