@@ -29,8 +29,5 @@ class GuiApp(object):
         self.app.exec_()
         
     def stop(self):
-        try:
-            self.thread.terminate()
-        except:
-            pass
+        pass
         
\ No newline at end of file
